==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/app/kotlin/inputs/CertificatePropertiesArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.app.kotlin.inputs

import com.pulumi.azurenative.app.inputs.CertificatePropertiesArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Certificate resource specific properties
 * @property password Certificate password.
 * @property value PFX or PEM blob
 */
public data class CertificatePropertiesArgs(
    public val password: Output<String>? = null,
    public val `value`: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.app.inputs.CertificatePropertiesArgs> {
    override fun toJava(): com.pulumi.azurenative.app.inputs.CertificatePropertiesArgs =
        com.pulumi.azurenative.app.inputs.CertificatePropertiesArgs.builder()
            .password(password?.applyValue({ args0 -> args0 }))
            .`value`(`value`?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [CertificatePropertiesArgs].
 */
@PulumiTagMarker
public class CertificatePropertiesArgsBuilder internal constructor() {
    private var password: Output<String>? = null

    private var `value`: Output<String>? = null

    /**
     * @param value Certificate password.
     */
    @JvmName("wtlwvndjqximquiu")
    public suspend fun password(`value`: Output<String>) {
        this.password = value
    }

    /**
     * @param value PFX or PEM blob
     */
    @JvmName("janyfvyhyalcwjsl")
    public suspend fun `value`(`value`: Output<String>) {
        this.`value` = value
    }

    /**
     * @param value Certificate password.
     */
    @JvmName("gtjkqghmohdwhuuo")
    public suspend fun password(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.password = mapped
    }

    /**
     * @param value PFX or PEM blob
     */
    @JvmName("imbjiyvsgsiulfau")
    public suspend fun `value`(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.`value` = mapped
    }

    internal fun build(): CertificatePropertiesArgs = CertificatePropertiesArgs(
        password = password,
        `value` = `value`,
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/app/kotlin/inputs/CertificatePropertiesArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.app.kotlin.inputs

import com.pulumi.azurenative.app.inputs.CertificatePropertiesArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Certificate resource specific properties
 * @property password Certificate password.
 * @property value PFX or PEM blob
 */
public data class CertificatePropertiesArgs(
    public val password: Output<String>? = null,
    public val `value`: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.app.inputs.CertificatePropertiesArgs> {
    override fun toJava(): com.pulumi.azurenative.app.inputs.CertificatePropertiesArgs =
        com.pulumi.azurenative.app.inputs.CertificatePropertiesArgs.builder()
            .password(password?.applyValue({ args0 -> args0 }))
            .`value`(`value`?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [CertificatePropertiesArgs].
 */
@PulumiTagMarker
public class CertificatePropertiesArgsBuilder internal constructor() {
    private var password: Output<String>? = null

    private var `value`: Output<String>? = null

    /**
     * @param value Certificate password.
     */
    @JvmName("nvubbmdvcjklmrds")
    public suspend fun password(`value`: Output<String>) {
        this.password = value
    }

    /**
     * @param value PFX or PEM blob
     */
    @JvmName("nkicndckfxmpqtir")
    public suspend fun `value`(`value`: Output<String>) {
        this.`value` = value
    }

    /**
     * @param value Certificate password.
     */
    @JvmName("rnfnecsulkuqgqwn")
    public suspend fun password(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.password = mapped
    }

    /**
     * @param value PFX or PEM blob
     */
    @JvmName("nbjsmdqnwmitpuww")
    public suspend fun `value`(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.`value` = mapped
    }

    internal fun build(): CertificatePropertiesArgs = CertificatePropertiesArgs(
        password = password,
        `value` = `value`,
    )
}
